/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSRule.h"
#include "CSSValue.h"
#include "CSSValueList.h"
#include "CanvasPixelArray.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLCollection.h"
#include "Node.h"
#include "StyleSheet.h"
#include "Text.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomCSSValue.h"
#include "gdom/GdomCSSValueList.h"
#include "gdom/PrivateGdomCSSValue.h"
#include "gdom/PrivateGdomCSSValueList.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateIntGdomCSSValue.h"
#include "gdom/PrivateIntGdomCSSValueList.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
} /* namespace WebCore */
extern "C" {

GDOMCSSValueList::GDOMCSSValueList(PassRefPtr<WebCore::CSSValueList> impl)
    : GDOMCSSValue(impl)
{
}

GdomCSSValue *
gdom_css_value_list_item (GdomCSSValueList *thiz, gulong index)
{
    g_return_val_if_fail (thiz, 0);
    WebCore::CSSValueList * item = (gdom_css_value_list_get_private(thiz));
    g_return_val_if_fail (item, 0);
    PassRefPtr<WebCore::CSSValue> g_res = WTF::getPtr(item->item(index));
    GdomCSSValue * res = static_cast<GdomCSSValue *>(WebCore::toGDOM(g_res.get()));
    return res;

}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "CSSValueList.h"
#include <gdom/GdomCSSValueList.h>
#include <gdom/PrivateGdomCSSValueList.h>
#include <gdom/PrivateIntGdomCSSValueList.h>
#include <gdom/GdomCSSValueListprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomCSSValueList, gdom_css_value_list, GDOM_TYPE_CSS_VALUE);

/*
struct _GdomCSSValueListPrivate {
    class WebCore::CSSValueList *item;
};

#define GDOM_CSS_VALUE_LIST_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_CSS_VALUE_LIST, GdomCSSValueListPrivate))
*/
G_END_DECLS
WebCore::CSSValueList *
gdom_css_value_list_get_private(GdomCSSValueList *request)
{
    GDOMCSSValueList *res;
    res = static_cast<GDOMCSSValueList*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::CSSValueList*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
    PROP_LENGTH,
};


static void gdom_css_value_list_finalize(GObject* object)
{
    /*GdomCSSValueList* request = GDOM_CSS_VALUE_LIST(object);*/
    /*GdomCSSValueListPrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_CSS_VALUE));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_css_value_list_parent_class)->finalize(object);
}

static void gdom_css_value_list__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomCSSValueList *self = GDOM_CSS_VALUE_LIST(object);
    WebCore::CSSValueList * gself = (gdom_css_value_list_get_private(self));
    switch (prop_id) {
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_css_value_list__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomCSSValueList *self = GDOM_CSS_VALUE_LIST(object);
    WebCore::CSSValueList * gself = (gdom_css_value_list_get_private(self));
    switch (prop_id) {
    case PROP_LENGTH:
    {
         g_value_set_ulong (value, gself->length());
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_css_value_list_class_init(GdomCSSValueListClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_css_value_list_finalize;
    g_klass->set_property = gdom_css_value_list__set_property_fn;
    g_klass->get_property = gdom_css_value_list__get_property_fn;

    g_object_class_install_property (g_klass, PROP_LENGTH,
            g_param_spec_ulong ("length", /* name */
                "css_value_list_length", /* short description */
                "read-only  gulong CSSValueList.length", /* longer - could do with some extra doc stuff here */
                 0,        /* min */
                G_MAXULONG, /* max */
                0,        /* default */
                 (GParamFlags)G_PARAM_READABLE));





    /*g_type_class_remove_private(requestClass, sizeof(GdomCSSValueListPrivate));*/
}

static void gdom_css_value_list_init(GdomCSSValueList* request)
{
    /*GdomCSSValueListPrivate* priv = GDOM_CSS_VALUE_LIST_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

